@@ -38,6 +38,7 @@ ServiceUpdateTypeType = Literal["security-update"]
 SourceTypeType = Literal["acl", "cluster", "node", "parameter-group", "subnet-group", "user"]
 ServiceName = Literal[
     "accessanalyzer",
+    "account",
     "acm",
     "acm-pca",
     "alexaforbusiness",
@@ -70,6 +71,7 @@ ServiceName = Literal[
     "chime-sdk-identity",
     "chime-sdk-messaging",
     "cloud9",
+    "cloudcontrol",
     "clouddirectory",
     "cloudformation",
     "cloudfront",
